@@ -1,7 +1,6 @@
 package Text::Password::AutoMigration;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
-use 5.008001;
 use Moose;
 extends 'Text::Password::SHA';
 
@@ -54,15 +53,15 @@ Or you can set default strength for password with param 'readablity'.
 
 It must be a Boolen, default is 1.
 
-If it was set as 0, you can generate more strong passwords with generate()
+If it was set as 0, you can generate stronger passwords with generate()
 
+ $pwd = Text::Pasword::AutoMiglation->new( readability => 0 );
+ 
 =back
 
 =head2 Methods and Subroutines
 
-=over
-
-=item verify( $raw, $hash )
+=head3 verify( $raw, $hash )
 
 returns true if the verify is success
 
@@ -74,33 +73,34 @@ override 'verify' => sub {
     die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
     if $input !~ /[!-~]/ or $input =~ /\s/;
 
-     return super() if $data =~ /^\$[56]\$([!-~]{1,8})\$[!-~]{43,86}$/
+     return super() if
+       $data =~ /^\$6\$[!-~]{1,8}\$[!-~]{86}$/
+    or $data =~ /^\$5\$[!-~]{1,8}\$[!-~]{43}$/
     or $data =~ /^[0-9a-f]{40}$/i;
     return $self->Text::Password::MD5::verify(@_);
 };
 
-=item nonce($length)
+=head3 nonce($length)
 
-generate the strings with enough strength
+generates the strings with enough strength
 
-default length is 8
+the length defaults to 8($self->default)
 
-=item encrypt($raw)
+=head3 encrypt($raw)
 
-returns hash with unix_sha512_crypt
+returns hash with unix_sha512_crypt()
 
 salt will be made automatically
-
-=item generate($length)
+ 
+=head3 generate($length)
 
 genarates pair of new password and it's hash
 
 not much readable characters(0Oo1Il|!2Zz5sS\$6b9qCcKkUuVvWwXx.,:;~\-^'"`) are fallen
+unless $self->readability is 0.
 
-default length is 8
-
-=back
-
+the length defaults to 8($self->default)
+ 
 =cut
 
 __PACKAGE__->meta->make_immutable;
@@ -110,6 +110,16 @@ no Moose;
 
 __END__
 
+=head1 SEE ALSO
+
+=over
+
+=item L<github|https://github.com/worthmine/Text-Password-AutoMigration>
+
+=item L<cpan|http://search.cpan.org/perldoc?Text%3A%3APassword%3A%3AAutoMigration>
+
+=back
+
 =head1 LICENSE
 
 Copyright (C) Yuki Yoshida(worthmine).
