@@ -1,8 +1,8 @@
 package Text::Password::CoreCrypt;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
-use 5.008001;
-use Moose;  # this module is NOT based on Moose but it need to succeed
+use 5.8.8;
+use Moose;
 
 has minimum => ( is => 'ro', isa => 'Int', default => 4 );
 has default => ( is => 'rw', isa => 'Int', default => 8 );
@@ -54,15 +54,15 @@ Or you can set default strength for password with param 'readablity'.
 
 It must be a Boolen, default is 1.
 
-If it was set as 0, you can generate more strong passwords with generate()
- 
+If it was set as 0, you can generate stronger passwords with generate()
+
+ $pwd = Text::Pasword::AutoMiglation->new( readability => 0 );
+
 =back
 
 =head2 Methods and Subroutines
 
-=over
-
-=item verify( $raw, $hash )
+=head3 verify( $raw, $hash )
 
 returns true if the verify is success
 
@@ -79,11 +79,11 @@ sub verify {
     return $data eq CORE::crypt( $input, $data );
 }
 
-=item nonce($length)
+=head3 nonce($length)
 
-generate the strings with enough strength
+generates the strings with enough strength
 
-default length is 8
+the length defaults to 8($self->default)
 
 =cut
 
@@ -101,9 +101,9 @@ sub nonce {
     return $n;
 }
 
-=item encrypt($raw)
+=head3 encrypt($raw)
 
-returns hash with CORE::crypt
+returns hash with CORE::crypt()
 
 salt will be made automatically
 
@@ -114,25 +114,26 @@ sub encrypt {
     my $input = shift;
     my $min = $self->minimum();
     croak __PACKAGE__ ." requires at least $min length" if length $input < $min;
-    die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
+     die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
     if $input !~ /[!-~]/ or $input =~ /\s/;
     carp __PACKAGE__ . " ignores the password with over 8bytes" unless $input =~ /^[!-~]{8}$/;
 
+    my $encrypt;
+    my @seeds = ( 'a' .. 'z', 'A' .. 'Z', 0 .. 9, '.', '/' );
     my $salt = '';
-    $salt .= $ascii[ rand @ascii ] until length $salt == 2;
+    $salt .= $seeds[ rand @seeds ] until length $salt == 2;
 
-    return CORE::crypt( $input, $salt );
+    return $encrypt = CORE::crypt( $input, $salt )
 }
 
-=item generate($length)
+=head3 generate($length)
 
 genarates pair of new password and it's hash
 
 not much readable characters(0Oo1Il|!2Zz5sS\$6b9qCcKkUuVvWwXx.,:;~\-^'"`) are fallen
+unless $self->readability is 0.
 
-default length is 8
-
-=back
+the length defaults to 8($self->default)
 
 =cut
 
