@@ -1,7 +1,6 @@
 package Text::Password::MD5;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
-use 5.008001;
 use Moose;
 extends 'Text::Password::CoreCrypt';
 
@@ -48,18 +47,18 @@ Or you can set default strength for password with param 'readablity'.
 
 It must be a Boolen, default is 1.
 
-If it was set as 0, you can generate more strong passwords with generate()
+If it was set as 0, you can generate stronger passwords with generate()
+
+ $pwd = Text::Pasword::AutoMiglation->new( readability => 0 );
  
 =back
 
 =head2 Methods and Subroutines
 
-=over
-
-=item verify( $raw, $hash )
+=head3 verify( $raw, $hash )
 
 returns true if the verify is success
- 
+
 =cut
 
 override 'verify' => sub {
@@ -75,15 +74,15 @@ override 'verify' => sub {
     return $data eq unix_md5_crypt( $input, $data );
 };
 
-=item nonce($length)
+=head3 nonce($length)
 
-generate the strings with enough strength
+generates the strings with enough strength
 
-default length is 8
+the length defaults to 8($self->default)
 
-=item encrypt($raw)
+=head3 encrypt($raw)
 
-returns hash with unix_md5_crypt
+returns hash with unix_md5_crypt()
 
 salt will be made automatically
 
@@ -104,15 +103,14 @@ override 'encrypt' => sub {
     return unix_md5_crypt( $input, $salt );
 };
 
-=item generate($length)
+=head3 generate($length)
 
 genarates pair of new password and it's hash
 
 not much readable characters(0Oo1Il|!2Zz5sS\$6b9qCcKkUuVvWwXx.,:;~\-^'"`) are fallen
+unless $self->readability is 0.
 
-default length is 8
-
-=back
+the length defaults to 8($self->default)
  
 =cut
 
